AgentLinkDirectory class final
Local directory Dart peers use to find a link owner.
Browsers cannot read this directory. They use AgentLinkAnnouncement.discover.
Constructors
- AgentLinkDirectory({Directory? root})
Properties
Methods
-
fileFor(
String protocolScheme) → File -
find(
String protocolScheme) → Future< AgentLinkAnnouncement?> -
Returns the record only when
GET /agent/discoveranswers the same scheme. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
AgentLinkAnnouncement announcement) → Future< void> -
remove(
String protocolScheme) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultRoot(
) → Directory